==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/arraycheck/MethodReturn.h <==
// class soot.jimple.toolkits.annotation.arraycheck.MethodReturn

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a2286d92c5b1b647 soot_jimple_toolkits_annotation_arraycheck_MethodReturn

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_MethodReturn_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_MethodReturn_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *, struct _jc_soot_SootMethod$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method$getMethod$04d7c221deab35ce(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *);
extern struct _jc_soot_Type$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *);
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method_info$getMethod$04d7c221deab35ce;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method_info$getType$847707b1f3b96fef;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *, struct _jc_java_lang_Object$object *);
	struct _jc_soot_SootMethod$object	*(*getMethod$04d7c221deab35ce)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *);
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vmethods	soot_jimple_toolkits_annotation_arraycheck_MethodReturn;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_refs {
	struct _jc_soot_SootMethod$object	*m;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_refs	soot_jimple_toolkits_annotation_arraycheck_MethodReturn;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_MethodReturn;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_MethodReturn, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_MethodReturn_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/arraycheck/MethodReturn.h <==
// class soot.jimple.toolkits.annotation.arraycheck.MethodReturn

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a2286d92c5b1b647 soot_jimple_toolkits_annotation_arraycheck_MethodReturn

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_MethodReturn_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_MethodReturn_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method$getMethod$04d7c221deab35ce(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method_info$getMethod$04d7c221deab35ce;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method_info$getType$847707b1f3b96fef;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_soot_SootMethod$object	*(*getMethod$04d7c221deab35ce)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vmethods	soot_jimple_toolkits_annotation_arraycheck_MethodReturn;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_refs {
	struct _jc_soot_SootMethod$object	*m;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_refs	soot_jimple_toolkits_annotation_arraycheck_MethodReturn;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_MethodReturn;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_MethodReturn, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_MethodReturn$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_MethodReturn_H_ */
